@@ -2,7 +2,7 @@ from .formatConvert.wav_pcm import  wav2pcm
 from .G160.G160 import cal_g160
 from .P563.P563 import cal_563_mos
 from .PESQ.PESQ import *
-from .POLQA.POLQA import cal_polqa
+from .POLQA.polqa_client import  polqa_client_test
 from .SDR.SDR import cal_sdr
 from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
