@@ -7,7 +7,7 @@ from formatConvert.wav_pcm import wav2pcm,pcm2wav
 from G160.G160 import cal_g160
 from P563.P563 import cal_563_mos
 from PESQ.PESQ import cal_pesq
-from POLQA.POLQA import cal_polqa
+from .POLQA.polqa_client import  polqa_client_test
 from SDR.SDR import cal_sdr
 from STI.cal_sti import cal_sti
 from STOI.STOI import cal_stoi
@@ -135,9 +135,10 @@ class computeAudioQuality():
         # pcm输入
         :return:
         """
-        self.__double_end_check()
-        curCH,curBwidth,curSR = self.__check_format(self.testFile)
-        return cal_polqa(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR)
+        return 0
+        # self.__double_end_check()
+        # curCH,curBwidth,curSR = self.__check_format(self.testFile)
+        # return polqa_client_test(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR)
 
 
     def PESQ(self):
