@@ -6,7 +6,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,sample
     """
 
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS，必选项
-    # g160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
+    # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
     # PESQ 窄带模式  8k   宽带模式 16k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -40,11 +40,12 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,sample
     return methodcaller(metrics)(comAuQUA)
 
 if __name__ == '__main__':
-    src = r'E:\martin\files\malePolqaWB.pcm'
+    src = r'E:\martin\files\out16000.wav'
     dst = r'E:\files\result.pcm'
-    test = r'E:\files\out16000.wav'
-    cle = r'E:\files\malePolqaWB.pcm'
-    #compute_audio_quality('G160',testFile=test,refFile=src,cleFile=cle)
-    print(compute_audio_quality('POLQA', testFile=src,refFile=src,samplerate=16000))
+    test = r'E:\files\out800016000.wav'
+    cle = r'E:\files\out16000_8000.pcm'
+    print(compute_audio_quality('G160',testFile=test,refFile=test,cleFile=cle))
+    #print(compute_audio_quality('G160', testFile=src,refFile=src,samplerate=16000))
+    print
 
     pass
\ No newline at end of file
